package com.srs.comprehensive.mapper;

import java.util.List;

import com.srs.comprehensive.domain.SrsKnrdTime;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 困难认定审核时间Mapper接口
 *
 * @author srs
 * @date 2024-06-05
 */
public interface SrsKnrdTimeMapper extends BaseMapper<SrsKnrdTime> {
    /**
     * 查询困难认定审核时间
     *
     * @param id 困难认定审核时间主键
     * @return 困难认定审核时间
     */
    public SrsKnrdTime selectSrsKnrdTimeById(Long id);

    /**
     * 查询困难认定审核时间列表
     *
     * @param srsKnrdTime 困难认定审核时间
     * @return 困难认定审核时间集合
     */
    List<SrsKnrdTime> selectSrsKnrdTimeList(SrsKnrdTime srsKnrdTime);

    /**
     * 新增困难认定审核时间
     *
     * @param srsKnrdTime 困难认定审核时间
     * @return 结果
     */
    int insertSrsKnrdTime(SrsKnrdTime srsKnrdTime);

    /**
     * 修改困难认定审核时间
     *
     * @param srsKnrdTime 困难认定审核时间
     * @return 结果
     */
    int updateSrsKnrdTime(SrsKnrdTime srsKnrdTime);

    /**
     * 删除困难认定审核时间
     *
     * @param id 困难认定审核时间主键
     * @return 结果
     */
    int deleteSrsKnrdTimeById(Long id);

    /**
     * 批量删除困难认定审核时间
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSrsKnrdTimeByIds(Long[] ids);
}
